@@ -4,6 +4,7 @@ var _pro_s_h_a_d_e__maths_8hpp =
     [ "BicubicInterpolator", "class_pro_s_h_a_d_e__internal__maths_1_1_bicubic_interpolator.html", "class_pro_s_h_a_d_e__internal__maths_1_1_bicubic_interpolator" ],
     [ "advanceGLPolyValue", "_pro_s_h_a_d_e__maths_8hpp.html#a4f2619c7f3b8d628af9cb356778e9807", null ],
     [ "arrayMedianAndIQR", "_pro_s_h_a_d_e__maths_8hpp.html#aa5a356017340781739a3bd66c716cfa5", null ],
+    [ "binReciprocalSpaceReflections", "_pro_s_h_a_d_e__maths_8hpp.html#aa2702798938d50ec2a55e46cbc31333e", null ],
     [ "completeLegendreSeries", "_pro_s_h_a_d_e__maths_8hpp.html#a31c91064de64aef9f8278d533f8188ad", null ],
     [ "complexMatrixSVDSigmasOnly", "_pro_s_h_a_d_e__maths_8hpp.html#ab98abe6f7fac976a70b608951dbdf993", null ],
     [ "complexMatrixSVDUandVOnly", "_pro_s_h_a_d_e__maths_8hpp.html#acdc79bf2506934c9ebbda9c13a2722ad", null ],
@@ -14,9 +15,12 @@ var _pro_s_h_a_d_e__maths_8hpp =
     [ "compute3x3MatrixInverse", "_pro_s_h_a_d_e__maths_8hpp.html#a83ac617b105e1ca1729800c5f290b567", null ],
     [ "compute3x3MatrixMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a5f2b9b9da97b52b7e5cccc08493d0e0d", null ],
     [ "compute3x3MatrixVectorMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a2f9c7716f6ab682e8548ab77efcdc444", null ],
+    [ "compute3x3MatrixVectorMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a6c83ae1b2f9783ad8df6ff6dfbbc3b9d", null ],
     [ "computeCrossProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a61807efeb86ea021f3d17ac531911c3c", null ],
     [ "computeDotProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a2ac3b534f974de25b092e9d48d9f7dea", null ],
     [ "computeDotProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a3b37ae1c35d048fd5dbff0a2cfcc4601", null ],
+    [ "computeFSC", "_pro_s_h_a_d_e__maths_8hpp.html#ad3c391ac63c921d19d8d4956d58e0ea8", null ],
+    [ "computeGaussian", "_pro_s_h_a_d_e__maths_8hpp.html#ad30fc4ec4f4239e4860270955a28fdcc", null ],
     [ "evaluateGLSeries", "_pro_s_h_a_d_e__maths_8hpp.html#a7e69b64278319ae1a1268d1a55545675", null ],
     [ "findAllPrimes", "_pro_s_h_a_d_e__maths_8hpp.html#a2454c19169bb38d616e52b99f1dc4495", null ],
     [ "findRotMatMatchingVectors", "_pro_s_h_a_d_e__maths_8hpp.html#a2b17617f8b3c42c5199948828cd1a57b", null ],
@@ -26,15 +30,17 @@ var _pro_s_h_a_d_e__maths_8hpp =
     [ "gaussLegendreIntegrationReal", "_pro_s_h_a_d_e__maths_8hpp.html#a62133f51851217e3cb28dff2f520d192", null ],
     [ "getAxisAngleFromRotationMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#aafc6f1626c7463de53c9f4f6fa11db22", null ],
     [ "getAxisAngleFromRotationMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#a4a379ad8635541b0c7f7f6349822b2a4", null ],
-    [ "getEulerZXZFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a5750d6f0bf8e4a4b1d26552e8719dfd4", null ],
-    [ "getEulerZXZFromAngleAxisFullSearch", "_pro_s_h_a_d_e__maths_8hpp.html#a0ade24485a9272a2d08dd6efb7a54d83", null ],
+    [ "getEulerZXZFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a91d9c1e755e7bf89e6de8f79fd4936df", null ],
     [ "getEulerZXZFromRotMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#ae6f6afcef5b90ca77d7d6a9e91824e28", null ],
     [ "getEulerZXZFromSOFTPosition", "_pro_s_h_a_d_e__maths_8hpp.html#acf6c5376edac98e54ef0e418cd05d706", null ],
     [ "getGLFirstEvenRoot", "_pro_s_h_a_d_e__maths_8hpp.html#a1823adaca871244e42347ecb8ed834a2", null ],
     [ "getGLPolyAtZero", "_pro_s_h_a_d_e__maths_8hpp.html#affab74b910cda2ee3faa461740a7a432", null ],
     [ "getLegendreAbscAndWeights", "_pro_s_h_a_d_e__maths_8hpp.html#a6e2f7de1bba288270ce2cc772d28d065", null ],
+    [ "getResolutionOfReflection", "_pro_s_h_a_d_e__maths_8hpp.html#a51be603bcedf202a40a490aa3fc8d45a", null ],
     [ "getRotationMatrixFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a39eafef902a49cc0816a2ed675c14a49", null ],
+    [ "getRotationMatrixFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a0860239f5ba95153f2b12d40a5742936", null ],
     [ "getRotationMatrixFromEulerZXZAngles", "_pro_s_h_a_d_e__maths_8hpp.html#abd9fe573a48f499dd7d1df4f779222f1", null ],
+    [ "getRotationMatrixFromEulerZXZAngles", "_pro_s_h_a_d_e__maths_8hpp.html#adccd7507561d95a44315b0eebe285272", null ],
     [ "getSOFTPositionFromEulerZXZ", "_pro_s_h_a_d_e__maths_8hpp.html#adea245a9b2b305f970be1ed62b141cce", null ],
     [ "isAxisUnique", "_pro_s_h_a_d_e__maths_8hpp.html#a2380a3710f7dbe672519c3adda30f7cd", null ],
     [ "isAxisUnique", "_pro_s_h_a_d_e__maths_8hpp.html#a49f093fbdd34498d27a4d8998b620c91", null ],
@@ -49,6 +55,7 @@ var _pro_s_h_a_d_e__maths_8hpp =
     [ "prepareBiCubicInterpolatorsPlusPlus", "_pro_s_h_a_d_e__maths_8hpp.html#ac3b355465dd2244b51e579dcb8669b3a", null ],
     [ "primeFactorsDecomp", "_pro_s_h_a_d_e__maths_8hpp.html#a6359dd366cdd986f5ad155bff8235a8e", null ],
     [ "rotationMatrixSimilarity", "_pro_s_h_a_d_e__maths_8hpp.html#a4348a7a36275c9cea20b5c27093c9b7e", null ],
+    [ "smoothen1D", "_pro_s_h_a_d_e__maths_8hpp.html#aa2da3e6dc4d41b8f09b47982fe74b3ea", null ],
     [ "transpose3x3MatrixInPlace", "_pro_s_h_a_d_e__maths_8hpp.html#ac6c48ee69a642f279354789f09b02296", null ],
     [ "vectorMeanAndSD", "_pro_s_h_a_d_e__maths_8hpp.html#a8a7c6330e101fb6d729aaf6f545db9c8", null ],
     [ "vectorMedianAndIQR", "_pro_s_h_a_d_e__maths_8hpp.html#af185ca14eb5d82fb126092767746e00a", null ],
