@@ -1,38 +1,33 @@
 var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
 [
-    [ "ProSHADE_data", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5e165ed8ecee7e07762aec7ac5890848", null ],
-    [ "ProSHADE_data", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a79b967d04959f83ae13b12b368caaf18", null ],
+    [ "ProSHADE_data", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a549bd90e8cdb71762a48aec59a313dd3", null ],
+    [ "ProSHADE_data", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7afb32f0574cb707876c4502680dfd80", null ],
     [ "~ProSHADE_data", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a485495727d37abd66295bab95d368438", null ],
     [ "addExtraSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7a402c710af1af5fabf7505848dad047", null ],
-    [ "allocateEMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#af42a5957efa2e6ec057059bd7c080eaf", null ],
-    [ "allocateRotatedSHMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4e3a1f3c2c0d13839244f30747b12394", null ],
-    [ "allocateRRPMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a6a3140fa92f0c3505a9ba02ee07997d2", null ],
+    [ "allocateEMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4e78c033b2c8c038038887105d67b115", null ],
+    [ "allocateRotatedSHMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa978d98f77a64fb16862b67a0de634be", null ],
+    [ "allocateRRPMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4f8698493efda1aa3e057c266d5c697b", null ],
     [ "allocateSO3CoeffsSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abc4a61da919ae37b0a03d23df2461224", null ],
-    [ "allocateWignerMatricesSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8b4f9cfa31af0209e934d2404967ed4a", null ],
+    [ "allocateWignerMatricesSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aea644c87703e005507e187aa0ffa64b7", null ],
     [ "centreMapOnCOM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a80ff45ef40549fb6a1d80b70865fc807", null ],
-    [ "computeGroupElementsForGroup", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a847c744261a8dc721efc4d6900cdd557", null ],
-    [ "computeGroupElementsForGroup", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4f4bb25b05f273a41bce8205f9058717", null ],
-    [ "computeOptimalTranslation", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aabab21be3199e734780b5ae8408b9fd5", null ],
+    [ "computeFSC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2b60ba4e2dd8ef4918b6f0ea5316a009", null ],
+    [ "computeFSC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a60643383ab239888adeee6e757876c80", null ],
+    [ "computeOptimalTranslation", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a68ac89c84a5e67582d050218566d9a44", null ],
     [ "computePdbRotationCentre", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa48fc72e389e663248d27eedbbf32314", null ],
-    [ "computeRotatedSH", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a569bda712a5ecedb260ac790db90efef", null ],
+    [ "computeRotatedSH", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad39f33c52f6d4f0db8e0d63ed0c9a2f3", null ],
     [ "computeRotationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac7cb89ed871668c57a3b5dc953c20482", null ],
     [ "computeRRPMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a6db2dcf87a6f763909ab08201e8de550", null ],
     [ "computeSphericalHarmonics", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a23f9a5f8f6fb7cf0f0324bc1d83d6090", null ],
     [ "computeTranslationMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a767640acbf4999201ce9ea86d76ff6a1", null ],
     [ "convertRotationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad96cd7a72fc56e7d97cfeff1086faad9", null ],
     [ "createNewMapFromBounds", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3349a7f6ffecc3ffd4e09192eb919248", null ],
-    [ "deepCopyMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a576bfe808729a1a224ac12263709b8dd", null ],
+    [ "deepCopyMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac3fbad5b8628112ace798950e6068bd4", null ],
     [ "detectSymmetryFromAngleAxisSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abcf770f9177a4d2f1a94a3adb20bf790", null ],
     [ "detectSymmetryInStructure", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afac05cfadc141435c4fc4a568ecffe29", null ],
-    [ "detectSymmetryInStructurePython", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3c589f8f2165cb1ad080b306dc0cbc25", null ],
     [ "figureIndexStartStop", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a476092aa08dff20d64a895e7b2227b2e", null ],
-    [ "findBestCScore", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae8df7d1c2855263e0c0d73a5474001e1", null ],
-    [ "findBestDScore", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac9989eaf9779a857f9c9e709bc0f3cf7", null ],
-    [ "findIScore", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a69c32bcbcdc6b5f58dc4659141b34fcd", null ],
     [ "findMapCOM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac07955296611dd411cf5ed87ced90571", null ],
-    [ "findOScore", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aedc04d6abaeebd3a2e8b26fb956d1996", null ],
     [ "findRequestedCSymmetryFromAngleAxis", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2714fcb2c08b224ccf09d64322bd2ab2", null ],
-    [ "findTScore", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa794c34ad9811fc68861bdeb132eaa1a", null ],
+    [ "findTopGroupSmooth", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a671ebb0985408bff451ec359b4df79b9", null ],
     [ "getAllGroupElements", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae2f2469c7d252c5e87d7bf9976b9b796", null ],
     [ "getAnySphereRadius", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a23620b34a604aca7db4d8b21f6d2d09a", null ],
     [ "getBestRotationMapPeaksEulerAngles", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a129f0b665c31fe2d6c7a03f1ba9997de", null ],
@@ -52,14 +47,16 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "getIntegrationWeight", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa150cfc5715420cf3d2e28c8af3631c4", null ],
     [ "getInternalMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a1bb8bf1e357cc25f68fe93554e44715d", null ],
     [ "getInvSO3Coeffs", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2eb10989a2f8d46b849cdaf8410b68be", null ],
+    [ "getMapCOMProcessChange", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4bd7a9a5ea6cac4302ec1cd80922c617", null ],
     [ "getMapValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afe04510c67e9dc9c19efaef8463b6e6e", null ],
     [ "getMaxBand", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a152b43815a3d3debd4b60751d9c8afdd", null ],
     [ "getMaxSpheres", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2245b15f279de574406204156089e5ef", null ],
     [ "getNoRecommendedSymmetryAxes", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad1fdcd9bdebc2900748821c5b3cb53cc", null ],
     [ "getOctahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a14c4d6044c5174afa8a0984025c45436", null ],
     [ "getOverlayRotationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad409e4556676857224d1f5e00e5b7911", null ],
-    [ "getPredictedIcosahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a73f96f10f0eb19f3fed57d956f75955e", null ],
-    [ "getPredictedOctahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abf0fecb2f515e41608cb1f4640691d74", null ],
+    [ "getPredictedIcosahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad9a02d8d68aac021572b764651aad0f1", null ],
+    [ "getPredictedOctahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae97b54a34689c1dceae47a5e8e94bbb0", null ],
+    [ "getPredictedTetrahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a931aa4c10c426c3b8041bd4e838b0678", null ],
     [ "getRealEMatrixValuesForLM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa757f9d32ebe20435661599652fd30fa", null ],
     [ "getRealRotFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8bc5fbad1079d42bfa73913a9e2df619", null ],
     [ "getRealSO3Coeffs", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a30eac0ab5b69c1b7190d6e56571ba8b8", null ],
@@ -73,7 +70,7 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "getShellBandwidth", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a898b48c1135e7a37f64f55e2367f0391", null ],
     [ "getSO3Coeffs", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae5c9c45b0db1e6a9eeef2ba292fbbcc3", null ],
     [ "getSpherePositions", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a188b648a0ad28b598d682ca14f288dc4", null ],
-    [ "getSpherePosValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3be93c3f8e860afc435750fa1c6c01d7", null ],
+    [ "getSpherePosValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a38d47eb11eafa106c65867ceec62a3fc", null ],
     [ "getSymmetryAxis", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0662f17e733fb6c1a16f04b273f8b7a5", null ],
     [ "getTetrahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a85bfab9b1babe0b35e6d81f525ead29b", null ],
     [ "getTranslationFnPointer", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae27a3e92905ca9d5f9a32c4eaacc64ae", null ],
@@ -93,14 +90,14 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "getZDimSize", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#af4d641d62864e4adf67c1365b0960970", null ],
     [ "getZFromPtr", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afbbcec01a6ee7701e3b1d0e61730fadf", null ],
     [ "getZToPtr", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a68eb739dd4846a1dd48032eb2cc3f49c", null ],
-    [ "interpolateMapFromSpheres", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a94e35e44abd71bec01e959cd0d106cfa", null ],
+    [ "interpolateMapFromSpheres", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9d11953ff54d5774659117be22bdb3b3", null ],
     [ "invertMirrorMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa67115a6b234764c958899863fb60b54", null ],
     [ "invertSHCoefficients", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac3dbae1c18d0550ee1940cadb5335684", null ],
     [ "mapToSpheres", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a56bfcfacedabd84ec54aa2843d59e014", null ],
     [ "maskMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0122be830893f5d82bab742be54d1ee7", null ],
     [ "normaliseEMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aceb19c915cebcef22c085cc6619cc472", null ],
     [ "normaliseMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a255bdb77824ce0fddc2454d5823219e1", null ],
-    [ "optimiseDihedralAngleFromAngleAxis", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aec8b3ae9e7ccaeaa8abeda92571a1d50", null ],
+    [ "prepareFSCFourierMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a51b1eb3cb274c1c68e85cf3cca0c25b7", null ],
     [ "processInternalMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afcb4202e9ffea1b99c59f73faf06d899", null ],
     [ "readInMAP", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a07fb6e354dcd90dc70f8b4fa8bba0c33", null ],
     [ "readInPDB", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abd1c1b3588308f775da5c8aeba3f3e78", null ],
@@ -109,11 +106,13 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "reportOverlayResults", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a43e3cad6f93a32f92194f76f0ec76a32", null ],
     [ "reportSymmetryResults", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abea2d62360b17cddca155816d3e485e8", null ],
     [ "reSampleMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ab573ea90a16991a06a77c5343328b060", null ],
-    [ "rotateMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8089b5dceb60b2e4c2e65957e24d1f56", null ],
+    [ "rotateMapRealSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7c7b69293bb883a84cde8031bb217f0a", null ],
+    [ "rotateMapRealSpaceInPlace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8c4f14e31f4ad0f08d4558b732ef4b8c", null ],
+    [ "rotateMapReciprocalSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa12ba3d9d61e240ec2d91d924e6cb0d3", null ],
     [ "saveDetectedSymmetries", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0b0608e80f20087b24cc9498767f0894", null ],
-    [ "saveRecommendedSymmetry", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9b62761850d8560e6f8c52a2249fe7b7", null ],
+    [ "saveRecommendedSymmetry", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a262b3b0e1129d4d3a5830a8982395f01", null ],
     [ "saveRequestedSymmetryC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a599a8fa1d6d780a45a2d772413bc778e", null ],
-    [ "saveRequestedSymmetryD", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a97c84fea7b9b77f73d3f15730751e070", null ],
+    [ "saveRequestedSymmetryD", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a51fec3f0a115640181f6e7ce102e4b37", null ],
     [ "setEMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aca5af5c8c3b18275e65ae4ebacd9877c", null ],
     [ "setIntegrationWeight", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3e7b1d5d4164ea7a6fda53c57ac979f4", null ],
     [ "setIntegrationWeightCumul", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a737ee01d968fef7ae1094847a0271033", null ],
@@ -122,7 +121,7 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "setWignerMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ab3aa4cdcd7cc9b458d7618077dfaab02", null ],
     [ "shellBandExists", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ada8e6f27f49afc3a0ee17758ce9e7594", null ],
     [ "so3CoeffsArrayIndex", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9f6ba75b25e201466929bfd4df75688d", null ],
-    [ "translateMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aee34d26604c8922b427da61781a3eff6", null ],
+    [ "translateMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7170576d4823143e7dd270e0f202d0b4", null ],
     [ "writeMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a81e6aab30488052e6bdd9b339e8124d8", null ],
     [ "writeMask", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aac87b1a87f32a742ea2b41014dac5f7b", null ],
     [ "writeOutOverlayFiles", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a6160812636f73e33c1c46a754b68a610", null ],
