@@ -4,13 +4,14 @@ var class_pro_s_h_a_d_e__settings =
     [ "ProSHADE_settings", "class_pro_s_h_a_d_e__settings.html#ae88f04ca81dc11f83329552e9f8e0d4c", null ],
     [ "~ProSHADE_settings", "class_pro_s_h_a_d_e__settings.html#a46ba91a2feeaccb274bc01aff5efb9c2", null ],
     [ "addStructure", "class_pro_s_h_a_d_e__settings.html#a0024967775d544e8512b6b157d53c1d1", null ],
-    [ "determineAllSHValues", "class_pro_s_h_a_d_e__settings.html#a46e32d9d122118fa08fd4f051f37e506", null ],
+    [ "determineAllSHValues", "class_pro_s_h_a_d_e__settings.html#a450e03005d24cc3e58d2d05fb3bc5027", null ],
     [ "determineBandwidth", "class_pro_s_h_a_d_e__settings.html#a46a4b300f5f4c507edcd208e1fcb9df7", null ],
     [ "determineBandwidthFromAngle", "class_pro_s_h_a_d_e__settings.html#a25080bd03aaf7a4ce834f0df7aaa4250", null ],
     [ "determineIntegrationOrder", "class_pro_s_h_a_d_e__settings.html#a6d2b5d90f31a1493e17474a044852da6", null ],
     [ "determineSphereDistances", "class_pro_s_h_a_d_e__settings.html#a4436b5eeb922db0351874eb64f350920", null ],
     [ "getCommandLineParams", "class_pro_s_h_a_d_e__settings.html#a52c1b3d4e86737c42785c0740b1f5497", null ],
     [ "printSettings", "class_pro_s_h_a_d_e__settings.html#a39cd81c30db3d72f279edb9b0c29a080", null ],
+    [ "setAppliedMaskFilename", "class_pro_s_h_a_d_e__settings.html#afd3ffe30dc16424e5cc72a6cf750daec", null ],
     [ "setAxisComparisonThreshold", "class_pro_s_h_a_d_e__settings.html#a41cdb46d64d149ee521b9a4e6ccee6de", null ],
     [ "setAxisComparisonThresholdBehaviour", "class_pro_s_h_a_d_e__settings.html#a74d3a2527a40c584af6bdb32896e8af0", null ],
     [ "setBandwidth", "class_pro_s_h_a_d_e__settings.html#a09da7265a83b7f5b6bef614f95a471d6", null ],
@@ -22,6 +23,7 @@ var class_pro_s_h_a_d_e__settings =
     [ "setEnergyLevelsComputation", "class_pro_s_h_a_d_e__settings.html#ad2d51c260ed88aaaa50dd7ca75bfc648", null ],
     [ "setEnLevShellWeight", "class_pro_s_h_a_d_e__settings.html#a07bb5091a2a7f008b6a5a3a74ad32681", null ],
     [ "setExtraSpace", "class_pro_s_h_a_d_e__settings.html#a4f6ef17085b2eb8181c66bd85648e513", null ],
+    [ "setFSCThreshold", "class_pro_s_h_a_d_e__settings.html#affdc86810291f09a7d70065fced76e91", null ],
     [ "setGroupingSmoothingFactor", "class_pro_s_h_a_d_e__settings.html#a8b666e89ab4352df317eb5c7c0cb446e", null ],
     [ "setIntegrationOrder", "class_pro_s_h_a_d_e__settings.html#a7889a7b3794f25cef3777436b1f199e3", null ],
     [ "setMapCentering", "class_pro_s_h_a_d_e__settings.html#a7b348b316612d2b20ae8c36ff2bce584", null ],
@@ -38,6 +40,7 @@ var class_pro_s_h_a_d_e__settings =
     [ "setMinimumMaskSize", "class_pro_s_h_a_d_e__settings.html#ad9684f6daecbcd47d3a0651cf46f6956", null ],
     [ "setMinimumPeakForAxis", "class_pro_s_h_a_d_e__settings.html#a2d8f84b127717648cf9aa1aa92ce7c0f", null ],
     [ "setMissingPeakThreshold", "class_pro_s_h_a_d_e__settings.html#a1a228d80e0516eed6ee8bbd81bd91a8a", null ],
+    [ "setNegativeDensity", "class_pro_s_h_a_d_e__settings.html#abd1069a4a110e954a516406eb70a8933", null ],
     [ "setNormalisation", "class_pro_s_h_a_d_e__settings.html#af5b8d95fdf6f00aee751bd688187f8cf", null ],
     [ "setOutputFilename", "class_pro_s_h_a_d_e__settings.html#a02204845243741c4d73353c0319fc9e2", null ],
     [ "setOverlayJsonFile", "class_pro_s_h_a_d_e__settings.html#a5d3d521f7d3c7e20d5980fe3deeedd3f", null ],
@@ -45,6 +48,7 @@ var class_pro_s_h_a_d_e__settings =
     [ "setPDBBFactor", "class_pro_s_h_a_d_e__settings.html#ab5e32721e570d63fba20e15be41428e0", null ],
     [ "setPeakNaiveNoIQR", "class_pro_s_h_a_d_e__settings.html#ab929802319773a9ae49a6e5cf9ae0c66", null ],
     [ "setPeakNeighboursNumber", "class_pro_s_h_a_d_e__settings.html#aa412b57c600caa1915c99bee1135d157", null ],
+    [ "setPeakThreshold", "class_pro_s_h_a_d_e__settings.html#a754c633261eb363bfb496a234ace79e6", null ],
     [ "setPhaseUsage", "class_pro_s_h_a_d_e__settings.html#a7666952b5e417490ba20b52a8e9a8c9d", null ],
     [ "setProgressiveSphereMapping", "class_pro_s_h_a_d_e__settings.html#aa8865b59b86447f584b92841113fde1e", null ],
     [ "setRecommendedFold", "class_pro_s_h_a_d_e__settings.html#a96a407a325278aec10d10a15c480c077", null ],
@@ -67,6 +71,7 @@ var class_pro_s_h_a_d_e__settings =
     [ "allDetectedIAxes", "class_pro_s_h_a_d_e__settings.html#aa4957b0a47193ef1042028dc22b350f6", null ],
     [ "allDetectedOAxes", "class_pro_s_h_a_d_e__settings.html#a4d869a528d0af64bc3688a9a48514061", null ],
     [ "allDetectedTAxes", "class_pro_s_h_a_d_e__settings.html#ae42ba1e294d1887c71b763f9bb5519cc", null ],
+    [ "appliedMaskFileName", "class_pro_s_h_a_d_e__settings.html#a670cffe28bbdac027bffd8f5491d4266", null ],
     [ "axisErrTolerance", "class_pro_s_h_a_d_e__settings.html#a4627b03c4064d3de15efb3ebbf57ed78", null ],
     [ "axisErrToleranceDefault", "class_pro_s_h_a_d_e__settings.html#a3894488e487198646796506ed44e468d", null ],
     [ "blurFactor", "class_pro_s_h_a_d_e__settings.html#a51c87d0b415c8eaa517dbb9b5496e7e9", null ],
@@ -83,6 +88,7 @@ var class_pro_s_h_a_d_e__settings =
     [ "firstModelOnly", "class_pro_s_h_a_d_e__settings.html#a0ee28b12499554d8dff8752cd5ef072a", null ],
     [ "forceBounds", "class_pro_s_h_a_d_e__settings.html#aa3e24ef5a66fa7204a2ba9c27f2f12b9", null ],
     [ "forceP1", "class_pro_s_h_a_d_e__settings.html#acffa14a2c2121b5b425fcabdb7b3ba6a", null ],
+    [ "fscThreshold", "class_pro_s_h_a_d_e__settings.html#a53120c9e4f3f1f69f80d7c966dff2cb7", null ],
     [ "halfMapKernel", "class_pro_s_h_a_d_e__settings.html#a8d2299cb1a7b0470e0f26e431af2548f", null ],
     [ "inputFiles", "class_pro_s_h_a_d_e__settings.html#a8a032c43a41e79e9d86c5beccb329169", null ],
     [ "integOrder", "class_pro_s_h_a_d_e__settings.html#af696bcba16302fe3a42e0341b4c5415a", null ],
@@ -101,10 +107,12 @@ var class_pro_s_h_a_d_e__settings =
     [ "overlayStructureName", "class_pro_s_h_a_d_e__settings.html#a833f51d5da64ed09004daa4bf66c013c", null ],
     [ "pdbBFactorNewVal", "class_pro_s_h_a_d_e__settings.html#a3cac1bd635aabf3a3370fc26dfa0f49a", null ],
     [ "peakNeighbours", "class_pro_s_h_a_d_e__settings.html#a26b57d39529ca69a117aceead6b12680", null ],
+    [ "peakThresholdMin", "class_pro_s_h_a_d_e__settings.html#a4af89abc1c94e4a6df28c7b31f576551", null ],
     [ "progressiveSphereMapping", "class_pro_s_h_a_d_e__settings.html#a2f1e4debc49664de8842d1b42be74d2d", null ],
     [ "reBoxMap", "class_pro_s_h_a_d_e__settings.html#a90f225894304c4894f6106498e1d7729", null ],
     [ "recommendedSymmetryFold", "class_pro_s_h_a_d_e__settings.html#ac8e62cc8dbd40265e51143c8207b6638", null ],
     [ "recommendedSymmetryType", "class_pro_s_h_a_d_e__settings.html#ac39560ba9aca9053753c158fb2adb9de", null ],
+    [ "removeNegativeDensity", "class_pro_s_h_a_d_e__settings.html#ad42474a333f9b605ccad7ecfb72afb2e", null ],
     [ "removeWaters", "class_pro_s_h_a_d_e__settings.html#acea4abeec3e2b45524e23809a69dce9d", null ],
     [ "requestedResolution", "class_pro_s_h_a_d_e__settings.html#a7d0a63b2ac89e4f0df85ce5053c6bd87", null ],
     [ "requestedSymmetryFold", "class_pro_s_h_a_d_e__settings.html#a6dc170d9826bad9ce4a2c31a033f7f6a", null ],
