@@ -32,7 +32,8 @@ var NAVTREE =
       [ "Installation", "index.html#install", [
         [ "Standard System Dependencies", "index.html#stdSys", null ],
         [ "Other dependencies", "index.html#otherDependencies", null ],
-        [ "Installing using CMake", "index.html#installBehaviour", null ],
+        [ "Installing on Windows", "index.html#winInstall", null ],
+        [ "Installing using CMake on Unix", "index.html#installBehaviour", null ],
         [ "Installation using pip", "index.html#pipInstall", null ]
       ] ],
       [ "Input PDB files", "index.html#pdbInput", [
@@ -84,9 +85,9 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "_pro_s_h_a_d_e_8cpp.html",
-"_pro_s_h_a_d_e__symmetry_8hpp.html#a5dc4353223fc752e0007b2adec193079",
-"class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad409e4556676857224d1f5e00e5b7911",
-"dir_fa9be34cc2c3eb9c0decdfb277595ca7.html"
+"_pro_s_h_a_d_e__spherical_harmonics_8hpp.html#aefc1302e14aeda70290390bda39da952",
+"class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa12ba3d9d61e240ec2d91d924e6cb0d3",
+"class_pro_s_h_a_d_e__settings.html#a8d2299cb1a7b0470e0f26e431af2548f"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
