@@ -1,18 +1,65 @@
 var NAVTREEINDEX3 =
 {
-"class_pro_s_h_a_d_e__settings.html#afb183823a47a73d459a5bae16042bf4e":[2,0,6,116],
-"class_pro_s_h_a_d_e__settings.html#afb39c3bb75f1b925175f9f6b09ada148":[2,0,6,114],
-"class_pro_s_h_a_d_e__settings.html#afb42ec0cd0f8abb54327c0e2c3025ed1":[2,0,6,61],
-"class_pro_s_h_a_d_e__settings.html#afcece610f52c27cadefb217f1d0c278c":[2,0,6,92],
-"class_pro_s_h_a_d_e__settings.html#affb17d9099f0b85b3af04a78d5c670f4":[2,0,6,87],
+"class_pro_s_h_a_d_e__settings.html#a8d2299cb1a7b0470e0f26e431af2548f":[2,0,7,89],
+"class_pro_s_h_a_d_e__settings.html#a904d9eb8c4ed8183f83ff6ae82da1921":[2,0,7,59],
+"class_pro_s_h_a_d_e__settings.html#a90f225894304c4894f6106498e1d7729":[2,0,7,109],
+"class_pro_s_h_a_d_e__settings.html#a96a407a325278aec10d10a15c480c077":[2,0,7,51],
+"class_pro_s_h_a_d_e__settings.html#a974bbe07f5435f052df4592825ed7aba":[2,0,7,52],
+"class_pro_s_h_a_d_e__settings.html#a9f2447c98c5d2f2aa0768f7599f8954f":[2,0,7,125],
+"class_pro_s_h_a_d_e__settings.html#aa3e24ef5a66fa7204a2ba9c27f2f12b9":[2,0,7,86],
+"class_pro_s_h_a_d_e__settings.html#aa412b57c600caa1915c99bee1135d157":[2,0,7,47],
+"class_pro_s_h_a_d_e__settings.html#aa4957b0a47193ef1042028dc22b350f6":[2,0,7,68],
+"class_pro_s_h_a_d_e__settings.html#aa6e624f5aac091c3be14d3cce4efeb1c":[2,0,7,36],
+"class_pro_s_h_a_d_e__settings.html#aa70d5ace2805cced4c22976fdaf29c23":[2,0,7,27],
+"class_pro_s_h_a_d_e__settings.html#aa84f6622f8b7ac034f171cbe29d3bcab":[2,0,7,57],
+"class_pro_s_h_a_d_e__settings.html#aa8865b59b86447f584b92841113fde1e":[2,0,7,50],
+"class_pro_s_h_a_d_e__settings.html#aa96a2a48c31635c52dbcebfa84851170":[2,0,7,30],
+"class_pro_s_h_a_d_e__settings.html#aaacee048ce8a3489edc77afcb54f0ca0":[2,0,7,19],
+"class_pro_s_h_a_d_e__settings.html#aae9f1582c7bceaa5898df7c5b38dd1c7":[2,0,7,33],
+"class_pro_s_h_a_d_e__settings.html#ab59297b3604ced939e30eaacd2eaaccb":[2,0,7,116],
+"class_pro_s_h_a_d_e__settings.html#ab5e32721e570d63fba20e15be41428e0":[2,0,7,45],
+"class_pro_s_h_a_d_e__settings.html#ab61d2183930ea26b3d49e7662052e83b":[2,0,7,77],
+"class_pro_s_h_a_d_e__settings.html#ab6b43957e2ff946c9c072f82432e1c4b":[2,0,7,28],
+"class_pro_s_h_a_d_e__settings.html#ab8d152f5e2e5dc0a64048d2e9c0d8d12":[2,0,7,126],
+"class_pro_s_h_a_d_e__settings.html#ab929802319773a9ae49a6e5cf9ae0c66":[2,0,7,46],
+"class_pro_s_h_a_d_e__settings.html#abd1069a4a110e954a516406eb70a8933":[2,0,7,40],
+"class_pro_s_h_a_d_e__settings.html#abebc53842ab9dd92685f66c950a2fc44":[2,0,7,123],
+"class_pro_s_h_a_d_e__settings.html#ac39560ba9aca9053753c158fb2adb9de":[2,0,7,111],
+"class_pro_s_h_a_d_e__settings.html#ac5b55f7ece119e9d9e980d89d59a6df8":[2,0,7,62],
+"class_pro_s_h_a_d_e__settings.html#ac61aa28892ae42710b7a90f4fdf9c05a":[2,0,7,64],
+"class_pro_s_h_a_d_e__settings.html#ac8e62cc8dbd40265e51143c8207b6638":[2,0,7,110],
+"class_pro_s_h_a_d_e__settings.html#ac914dc8b6ee2e35286beabb1b6611b74":[2,0,7,99],
+"class_pro_s_h_a_d_e__settings.html#acea4abeec3e2b45524e23809a69dce9d":[2,0,7,113],
+"class_pro_s_h_a_d_e__settings.html#acf005edf3e38fe6050d25f8910d3f079":[2,0,7,60],
+"class_pro_s_h_a_d_e__settings.html#acffa14a2c2121b5b425fcabdb7b3ba6a":[2,0,7,87],
+"class_pro_s_h_a_d_e__settings.html#ad2d51c260ed88aaaa50dd7ca75bfc648":[2,0,7,20],
+"class_pro_s_h_a_d_e__settings.html#ad42474a333f9b605ccad7ecfb72afb2e":[2,0,7,112],
+"class_pro_s_h_a_d_e__settings.html#ad7070cc8a98a8b8a040232eae8b2fbf3":[2,0,7,82],
+"class_pro_s_h_a_d_e__settings.html#ad9684f6daecbcd47d3a0651cf46f6956":[2,0,7,37],
+"class_pro_s_h_a_d_e__settings.html#ad9c57832756d4ea342589104cdaded6b":[2,0,7,117],
+"class_pro_s_h_a_d_e__settings.html#adbe7012b771262d46b4a6c175c66f6ab":[2,0,7,44],
+"class_pro_s_h_a_d_e__settings.html#adc025bad387952e9a2b9395775ad7903":[2,0,7,56],
+"class_pro_s_h_a_d_e__settings.html#add15920c73e6255d517e2d97794bcdd5":[2,0,7,17],
+"class_pro_s_h_a_d_e__settings.html#ae42ba1e294d1887c71b763f9bb5519cc":[2,0,7,70],
+"class_pro_s_h_a_d_e__settings.html#ae7aad96d952d4ca192d11be5b72d47c6":[2,0,7,29],
+"class_pro_s_h_a_d_e__settings.html#ae88f04ca81dc11f83329552e9f8e0d4c":[2,0,7,1],
+"class_pro_s_h_a_d_e__settings.html#af5b8d95fdf6f00aee751bd688187f8cf":[2,0,7,41],
+"class_pro_s_h_a_d_e__settings.html#af696bcba16302fe3a42e0341b4c5415a":[2,0,7,91],
+"class_pro_s_h_a_d_e__settings.html#afb183823a47a73d459a5bae16042bf4e":[2,0,7,124],
+"class_pro_s_h_a_d_e__settings.html#afb39c3bb75f1b925175f9f6b09ada148":[2,0,7,122],
+"class_pro_s_h_a_d_e__settings.html#afb42ec0cd0f8abb54327c0e2c3025ed1":[2,0,7,65],
+"class_pro_s_h_a_d_e__settings.html#afcece610f52c27cadefb217f1d0c278c":[2,0,7,98],
+"class_pro_s_h_a_d_e__settings.html#afd3ffe30dc16424e5cc72a6cf750daec":[2,0,7,11],
+"class_pro_s_h_a_d_e__settings.html#affb17d9099f0b85b3af04a78d5c670f4":[2,0,7,93],
+"class_pro_s_h_a_d_e__settings.html#affdc86810291f09a7d70065fced76e91":[2,0,7,23],
 "classes.html":[2,1],
 "dir_031c4fc26031de218e3c67acfca35073.html":[3,0,0,0],
 "dir_5c0d64f70903e893b1efe571a4b8de29.html":[3,0,0,2],
 "dir_68267d1309a1af8e8297ef4c3efbcdba.html":[3,0,0],
 "dir_fa9be34cc2c3eb9c0decdfb277595ca7.html":[3,0,0,1],
 "files.html":[3,0],
-"functions.html":[2,3,0,0],
 "functions.html":[2,3,0],
+"functions.html":[2,3,0,0],
 "functions_b.html":[2,3,0,1],
 "functions_c.html":[2,3,0,2],
 "functions_d.html":[2,3,0,3],
@@ -28,13 +75,14 @@ var NAVTREEINDEX3 =
 "functions_func_i.html":[2,3,1,6],
 "functions_func_m.html":[2,3,1,7],
 "functions_func_n.html":[2,3,1,8],
-"functions_func_p.html":[2,3,1,9],
-"functions_func_r.html":[2,3,1,10],
-"functions_func_s.html":[2,3,1,11],
-"functions_func_t.html":[2,3,1,12],
-"functions_func_w.html":[2,3,1,13],
-"functions_func_z.html":[2,3,1,14],
-"functions_func_~.html":[2,3,1,15],
+"functions_func_o.html":[2,3,1,9],
+"functions_func_p.html":[2,3,1,10],
+"functions_func_r.html":[2,3,1,11],
+"functions_func_s.html":[2,3,1,12],
+"functions_func_t.html":[2,3,1,13],
+"functions_func_w.html":[2,3,1,14],
+"functions_func_z.html":[2,3,1,15],
+"functions_func_~.html":[2,3,1,16],
 "functions_g.html":[2,3,0,6],
 "functions_h.html":[2,3,0,7],
 "functions_i.html":[2,3,0,8],
@@ -92,9 +140,10 @@ var NAVTREEINDEX3 =
 "namespace_pro_s_h_a_d_e__internal__misc.html":[1,0,6],
 "namespace_pro_s_h_a_d_e__internal__overlay.html":[1,0,7],
 "namespace_pro_s_h_a_d_e__internal__peak_search.html":[1,0,8],
+"namespace_pro_s_h_a_d_e__internal__precomputed_vals.html":[2,0,2],
 "namespace_pro_s_h_a_d_e__internal__precomputed_vals.html":[1,0,9],
+"namespace_pro_s_h_a_d_e__internal__spheres.html":[2,0,3],
 "namespace_pro_s_h_a_d_e__internal__spheres.html":[1,0,10],
-"namespace_pro_s_h_a_d_e__internal__spheres.html":[2,0,2],
 "namespace_pro_s_h_a_d_e__internal__spherical_harmonics.html":[1,0,11],
 "namespace_pro_s_h_a_d_e__internal__symmetry.html":[1,0,12],
 "namespace_pro_s_h_a_d_e__internal__tasks.html":[1,0,13],
@@ -106,8 +155,8 @@ var NAVTREEINDEX3 =
 "namespacemembers_d.html":[1,1,0,3],
 "namespacemembers_e.html":[1,1,0,4],
 "namespacemembers_f.html":[1,1,0,5],
-"namespacemembers_func.html":[1,1,1],
 "namespacemembers_func.html":[1,1,1,0],
+"namespacemembers_func.html":[1,1,1],
 "namespacemembers_func_b.html":[1,1,1,1],
 "namespacemembers_func_c.html":[1,1,1,2],
 "namespacemembers_func_d.html":[1,1,1,3],
