@@ -16,8 +16,8 @@
 
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.5.3
-    \date      FEB 2021
+    \version   0.7.6.0
+    \date      JUL 2021
 */
 
 //==================================================== ProSHADE
@@ -38,6 +38,7 @@ int main ( int argc, char **argv )
     
     //================================================ Further useful settings
     settings->forceP1                                 = true;                                // Should PDB files be forced to have P1 spacegroup?
+    settings->setNegativeDensity                      ( true );                              // Should the negative density be removed from input files?
     settings->removeWaters                            = true;                                // Should PDB files have their water molecules removed?
     settings->firstModelOnly                          = true;                                // Should PDB files have only their first model used, or should ProSHADE use all models?
     settings->setProgressiveSphereMapping             ( false );                             // Should smaller spheres be less sampled? It is considerably faster, but may sacrifice some (little) accuracy.
@@ -55,6 +56,8 @@ int main ( int argc, char **argv )
     settings->setSymmetryRotFunPeaks                  ( true );                              // Should the new angle-axis space symmetry detection be used?
     settings->setBicubicInterpolationSearch           ( true );                              // Should bi-cubic interpolation between peak grid indices be done?
     settings->setMaxSymmetryFold                      ( 30 );                                // The maximum prime number fold that will be searched for.
+    settings->setFSCThreshold                         ( 0.75 );                              // Sets the minimum FSC threshold for axis to be considered detected.
+    settings->setPeakThreshold                        ( 0.80 );                              // Sets the minimum peak height threshold for axis to be considered possible.
     settings->setPeakNeighboursNumber                 ( 1 );                                 // Numer of points in each direction which needs to be lower in order for the central point to be considered a peak.
     settings->setPeakNaiveNoIQR                       ( -999.9 );                            // Peak searching threshold for too low peaks in number of inter-quartile ranges from median of the non-peak point values.
     settings->setMissingPeakThreshold                 ( 0.3 );                               // Fraction of peaks that can be missing for missing axis search to be initiated.
@@ -81,6 +84,7 @@ int main ( int argc, char **argv )
     settings->setMaskIQR                              ( 3.0 );                               // Number of inter-quartile ranges from median to use as the masking threshold.
     settings->setMaskSaving                           ( false );                             // Should map mask be saved?
     settings->setMaskFilename                         ( "maskFile" );                        // The filename (no extension) to which the map masks will be saved into.
+    settings->setAppliedMaskFilename                  ( "" );                                // The filename from which mask data will be read from.
 
     //================================================ Print all the settings values
 //    settings->printSettings                           ( );                                   // Prints all the ProSHADE_settings values. Mostly for debugging purposes.
@@ -107,13 +111,13 @@ int main ( int argc, char **argv )
     std::cout << "Rot. Centre to optimal overlay translation:  " << originToOverlay.at(0) << " ; " << originToOverlay.at(1) << " ; " << originToOverlay.at(2) << std::endl;
     
     //================================================ Expected out is (except for the output files, which will be named overlayResuls.map and overlayResuls.pdb)
-//  Optimal rotation Euler angles are:           5.43251 ; 0.752641 ; 3.92701
-//  Optimal rotation matrix is       :           -0.871914 ; -0.0783577 ; 0.483348
-//                                   :           -0.19118 ; -0.854289 ; -0.483364
-//                                   :           0.450795 ; -0.513858 ; 0.729886
-//  Rot. Centre to origin translation:           -16 ; -20 ; -24
-//  Rot. Centre to optimal overlay translation:  8 ; 8 ; -6
-//  Optimal rotation Euler angles are:           5.43251 ; 0.752641 ; 3.92701
+//  Optimal rotation Euler angles are:           3.88623 ; 0.744047 ; 5.45676
+//  Optimal rotation matrix is       :           -0.865 ; 0.203035 ; -0.458859
+//                                   :           0.0612312 ; -0.864932 ; -0.498141
+//                                   :           -0.498022 ; -0.458988 ; 0.735734
+//  Rot. Centre to origin translation:           -17 ; -21 ; -23
+//  Rot. Centre to optimal overlay translation:  4 ; 4 ; -4
+//  Optimal rotation Euler angles are:           3.88623 ; 0.744047 ; 5.45676
     
     //================================================ DONE
     return EXIT_SUCCESS;
