@@ -15,16 +15,16 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.5.3
-    \date      FEB 2021
+    \version   0.7.6.0
+    \date      JUL 2021
  */
 
 //============================================ ProSHADE
 #include "ProSHADE_exceptions.hpp"
 
 //============================================ Overinclusion protection
-#ifndef __PROSHADE_MESSAGES__
-#define __PROSHADE_MESSAGES__
+#ifndef PROSHADE_MESSAGES
+#define PROSHADE_MESSAGES
 
 //============================================ ProSHADE_internal_messages Namespace
 /*! \namespace ProSHADE_internal_messages
@@ -39,7 +39,7 @@ namespace ProSHADE_internal_messages
     void printTerminateMessage                        ( proshade_signed verbose );
     void printProgressMessage                         ( proshade_signed verbose, proshade_signed messageLevel, std::string message );
     void printWarningMessage                          ( proshade_signed verbose, std::string message, std::string warnCode );
-    void printHelp                                    ( void );
+    void printHelp  [[noreturn]]                      ( void );
 }
 
 #endif
