@@ -15,16 +15,16 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.5.3
-    \date      FEB 2021
+    \version   0.7.6.0
+    \date      JUL 2021
  */
 
 //==================================================== ProSHADE
-#include "ProSHADE_data.hpp"
+#include "ProSHADE_spheres.hpp"
 
 //==================================================== Overinclusion protection
-#ifndef __PROSHADE_PEAKSEARCH__
-#define __PROSHADE_PEAKSEARCH__
+#ifndef PROSHADE_PEAKSEARCH
+#define PROSHADE_PEAKSEARCH
 
 //==================================================== ProSHADE_internal_peakSearch Namespace
 /*! \namespace ProSHADE_internal_peakSearch
@@ -84,6 +84,7 @@ namespace ProSHADE_internal_peakSearch
     void getBestPeakEulerAngsSmoothedZ                ( proshade_complex* map, proshade_unsign dim, proshade_double smoothingFraction,
                                                         proshade_double noIQRs, proshade_signed peakSize, proshade_double* eulA, proshade_double* eulB,
                                                         proshade_double* eulG );
+    std::vector< proshade_signed > findPeaks1D        ( std::vector< proshade_double > data );
 }
 
 #endif
