@@ -15,72 +15,16 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.5.3
-    \date      FEB 2021
+    \version   0.7.6.0
+    \date      JUL 2021
  */
 
 //==================================================== ProSHADE
 #include "ProSHADE_maths.hpp"
 
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wpedantic"
-#pragma GCC diagnostic ignored "-Wshadow"
-#pragma GCC diagnostic ignored "-Wall"
-
-//==================================================== Gemmi
-#ifndef __PROSHADE_GEMMI_INCLUDE__
-    #define __PROSHADE_GEMMI_INCLUDE__
-    #include <gemmi/mmread.hpp>
-    #include <gemmi/ccp4.hpp>
-    #include <gemmi/it92.hpp>
-    #include <gemmi/dencalc.hpp>
-    #include <gemmi/fprime.hpp>
-    #include <gemmi/gz.hpp>
-#endif
-
-//==================================================== FFTW3
-#ifdef __cplusplus
-extern "C" {
-#endif
-    
-#include <fftw3.h>
-    
-#ifdef __cplusplus
-}
-#endif
-
-//==================================================== SOFT
-#ifdef __cplusplus
-extern "C" {
-#endif
-    
-#include <wrap_fftw.h>
-#include <makeweights.h>
-#include <s2_primitive.h>
-#include <s2_cospmls.h>
-#include <s2_legendreTransforms.h>
-#include <s2_semi_fly.h>
-#include <rotate_so3_utils.h>
-#include <utils_so3.h>
-#include <soft_fftw.h>
-#include <rotate_so3_fftw.h>
-    
-#ifdef __cplusplus
-}
-#endif
-
-#pragma GCC diagnostic pop
-
-//==================================================== GetOpt port (BSD License, works on Windows as well)
-#if defined ( _WIN64 ) || defined ( _WIN32 )
-    #include <getopt_port/getopt.h>
-#else
-    #include <getopt.h>
-#endif
-
 //==================================================== Overinclusion protection
-#ifndef __PROSHADE_SETTINGS__
-#define __PROSHADE_SETTINGS__
+#ifndef PROSHADE_SETTINGS
+#define PROSHADE_SETTINGS
 
 /*! \class ProSHADE_settings
     \brief This class stores all the settings and is passed to the executive classes instead of a multitude of parameters.
@@ -91,7 +35,7 @@ extern "C" {
  */
 class ProSHADE_settings
 {
-public:
+public: 
     //================================================ Settings regarding the task at hand
     ProSHADE_Task task;                               //!< This custom type variable determines which task to perfom (i.e. symmetry detection, distances computation, etc.).
     
@@ -100,6 +44,7 @@ public:
     bool forceP1;                                     //!< Should the P1 spacegroup be forced on the input PDB files?
     bool removeWaters;                                //!< Should all waters be removed from input PDB files?
     bool firstModelOnly;                              //!< Shoud only the first PDB model be used, or should all models be used?
+    bool removeNegativeDensity;                       //!< Should the negative density be removed from input files?
     
     //================================================ Settings regarding the resolution of calculations
     proshade_single requestedResolution;              //!< The resolution to which the calculations are to be done.
@@ -138,6 +83,7 @@ public:
     proshade_single correlationKernel;                //!< This value in Angstrom will be used as the kernel for the map-FHM correlation computation.
     bool saveMask;                                    //!< Should the mask be saved?
     std::string maskFileName;                         //!< The filename to which mask should be saved.
+    std::string appliedMaskFileName;                  //!< The filename from which mask data will be read from.
     
     //================================================ Settings regarding re-boxing
     bool reBoxMap;                                    //!< This switch decides whether re-boxing is needed.
@@ -183,6 +129,8 @@ public:
     bool usePeakSearchInRotationFunctionSpace;        //!< This variable switch decides whether symmetry detection will be done using peak search in rotation function or using the angle-axis sperical space.
     bool useBiCubicInterpolationOnPeaks;              //!< This variable switch decides whether best symmetry is detected from peak indices, or whether bicubic interpolation is done to seatch for better axis between indices.
     proshade_unsign maxSymmetryFold;                  //!< The highest symmetry fold to search for.
+    proshade_double fscThreshold;                     //!< The threshold for FSC value under which the axis is considered to be likely noise.
+    proshade_double peakThresholdMin;                 //!< The threshold for peak height above which axes are considered possible.
     
     //================================================ Settings regarding the structure overlay
     std::string overlayStructureName;                 //!< The filename to which the rotated and translated moving structure is to be saved.
@@ -206,16 +154,79 @@ public: // maybe make this protected?
     void determineBandwidth                           ( proshade_unsign circumference );
     void determineSphereDistances                     ( proshade_single maxMapRange );
     void determineIntegrationOrder                    ( proshade_single maxMapRange );
-    void determineAllSHValues                         ( proshade_unsign xDim, proshade_unsign yDim, proshade_unsign zDim );
+    void determineAllSHValues                         ( proshade_unsign xDim, proshade_unsign yDim, proshade_single xDimAngs,
+                                                        proshade_single yDimAngs, proshade_single zDimAngs );
     void setVariablesLeftOnAuto                       ( void );
     
 public:
     //================================================ Constructors / Destructors
+#if defined ( _WIN64 ) || defined ( _WIN32 )
+    __declspec(dllexport)  ProSHADE_settings          ( );
+    __declspec(dllexport)  ProSHADE_settings          ( ProSHADE_Task task );
+    __declspec(dllexport) ~ProSHADE_settings          ( );
+#else
     ProSHADE_settings                                 ( void );
     ProSHADE_settings                                 ( ProSHADE_Task task );
    ~ProSHADE_settings                                 ( void );
+#endif
     
     //================================================ Variable setting functions
+#if defined ( _WIN64 ) || defined ( _WIN32 )
+    void __declspec(dllexport) addStructure                                   ( std::string structure );
+    void __declspec(dllexport) setResolution                                  ( proshade_single resolution );
+    void __declspec(dllexport) setPDBBFactor                                  ( proshade_double newBF );
+    void __declspec(dllexport) setNormalisation                               ( bool normalise );
+    void __declspec(dllexport) setMapInversion                                ( bool mInv );
+    void __declspec(dllexport) setVerbosity                                   ( proshade_signed verbosity );
+    void __declspec(dllexport) setMaskBlurFactor                              ( proshade_single blurFac );
+    void __declspec(dllexport) setMaskIQR                                     ( proshade_single noIQRs );
+    void __declspec(dllexport) setMasking                                     ( bool mask );
+    void __declspec(dllexport) setCorrelationMasking                          ( bool corMask );
+    void __declspec(dllexport) setTypicalNoiseSize                            ( proshade_single typNoi );
+    void __declspec(dllexport) setMinimumMaskSize                             ( proshade_single minMS );
+    void __declspec(dllexport) setMaskSaving                                  ( bool savMsk );
+    void __declspec(dllexport) setMaskFilename                                ( std::string mskFln );
+    void __declspec(dllexport) setAppliedMaskFilename                         ( std::string mskFln );
+    void __declspec(dllexport) setMapReboxing                                 ( bool reBx );
+    void __declspec(dllexport) setBoundsSpace                                 ( proshade_single boundsExSp );
+    void __declspec(dllexport) setBoundsThreshold                             ( proshade_signed boundsThres );
+    void __declspec(dllexport) setSameBoundaries                              ( bool sameB );
+    void __declspec(dllexport) setOutputFilename                              ( std::string oFileName );
+    void __declspec(dllexport) setMapResolutionChange                         ( bool mrChange );
+    void __declspec(dllexport) setMapResolutionChangeTriLinear                ( bool mrChange );
+    void __declspec(dllexport) setMapCentering                                ( bool com );
+    void __declspec(dllexport) setExtraSpace                                  ( proshade_single exSpace );
+    void __declspec(dllexport) setBandwidth                                   ( proshade_unsign band );
+    void __declspec(dllexport) setSphereDistances                             ( proshade_single sphDist );
+    void __declspec(dllexport) setIntegrationOrder                            ( proshade_unsign intOrd );
+    void __declspec(dllexport) setTaylorSeriesCap                             ( proshade_unsign tayCap );
+    void __declspec(dllexport) setProgressiveSphereMapping                    ( bool progSphMap );
+    void __declspec(dllexport) setEnergyLevelsComputation                     ( bool enLevDesc );
+    void __declspec(dllexport) setTraceSigmaComputation                       ( bool trSigVal );
+    void __declspec(dllexport) setRotationFunctionComputation                 ( bool rotfVal );
+    void __declspec(dllexport) setPeakNeighboursNumber                        ( proshade_unsign pkS );
+    void __declspec(dllexport) setPeakNaiveNoIQR                              ( proshade_double noIQRs );
+    void __declspec(dllexport) setPhaseUsage                                  ( bool phaseUsage );
+    void __declspec(dllexport) setEnLevShellWeight                            ( proshade_double mPower );
+    void __declspec(dllexport) setGroupingSmoothingFactor                     ( proshade_double smFact );
+    void __declspec(dllexport) setMissingPeakThreshold                        ( proshade_double mpThres );
+    void __declspec(dllexport) setAxisComparisonThreshold                     ( proshade_double axThres );
+    void __declspec(dllexport) setAxisComparisonThresholdBehaviour            ( bool behav );
+    void __declspec(dllexport) setMinimumPeakForAxis                          ( proshade_double minSP );
+    void __declspec(dllexport) setRecommendedSymmetry                         ( std::string val );
+    void __declspec(dllexport) setRecommendedFold                             ( proshade_unsign val );
+    void __declspec(dllexport) setRequestedSymmetry                           ( std::string val );
+    void __declspec(dllexport) setRequestedFold                               ( proshade_unsign val );
+    void __declspec(dllexport) setDetectedSymmetry                            ( proshade_double* sym );
+    void __declspec(dllexport) setOverlaySaveFile                             ( std::string filename );
+    void __declspec(dllexport) setOverlayJsonFile                             ( std::string filename );
+    void __declspec(dllexport) setSymmetryRotFunPeaks                         ( bool rotFunPeaks );
+    void __declspec(dllexport) setBicubicInterpolationSearch                  ( bool bicubPeaks );
+    void __declspec(dllexport) setMaxSymmetryFold                             ( proshade_unsign maxFold );
+    void __declspec(dllexport) setFSCThreshold                                ( proshade_double fscThr );
+    void __declspec(dllexport) setPeakThreshold                               ( proshade_double peakThr );
+    void __declspec(dllexport) setNegativeDensity                             ( bool nDens );
+#else
     void addStructure                                 ( std::string structure );
     void setResolution                                ( proshade_single resolution );
     void setPDBBFactor                                ( proshade_double newBF );
@@ -230,6 +241,7 @@ public:
     void setMinimumMaskSize                           ( proshade_single minMS );
     void setMaskSaving                                ( bool savMsk );
     void setMaskFilename                              ( std::string mskFln );
+    void setAppliedMaskFilename                       ( std::string mskFln );
     void setMapReboxing                               ( bool reBx );
     void setBoundsSpace                               ( proshade_single boundsExSp );
     void setBoundsThreshold                           ( proshade_signed boundsThres );
@@ -266,12 +278,24 @@ public:
     void setSymmetryRotFunPeaks                       ( bool rotFunPeaks );
     void setBicubicInterpolationSearch                ( bool bicubPeaks );
     void setMaxSymmetryFold                           ( proshade_unsign maxFold );
+    void setFSCThreshold                              ( proshade_double fscThr );
+    void setPeakThreshold                             ( proshade_double peakThr );
+    void setNegativeDensity                           ( bool nDens );
+#endif
     
     //================================================ Command line options parsing
-    void getCommandLineParams                         ( int argc, char** argv );
+#if defined ( _WIN64 ) || defined ( _WIN32 )
+    void __declspec(dllexport) getCommandLineParams   ( int argc, char** argv );
+#else
+    void                       getCommandLineParams   ( int argc, char** argv );
+#endif
     
     //================================================ Debugging
-    void printSettings                                ( void );
+#if defined ( _WIN64 ) || defined ( _WIN32 )
+    void __declspec(dllexport) printSettings          ( void );
+#else
+    void                       printSettings          ( void );
+#endif
 };
 
 #endif
