@@ -15,8 +15,8 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.5.3
-    \date      FEB 2021
+    \version   0.7.6.0
+    \date      JUL 2021
  */
 
 //==================================================== ProSHADE
@@ -33,11 +33,10 @@
     \param[in] outputReal The real part of the output will be saved here.
     \param[in] outputImag The immaginary part of the output will be saved here.
     \param[in] shWeights The weights for spherical harmonics computation will be stored here.
-    \param[in] tableSpace Space where the legendre polynomials table will be stored.
     \param[in] tableSpaceHelper This space is required by SOFT for pre-computing values into this table.
     \param[in] workspace The space where multiple minor results are saved by SOFT.
  */
-void ProSHADE_internal_sphericalHarmonics::allocateComputationMemory ( proshade_unsign band, proshade_double*& inputReal, proshade_double*& inputImag, proshade_double*& outputReal, proshade_double*& outputImag, proshade_double*& shWeights, double**& tableSpace, proshade_double*& tableSpaceHelper, fftw_complex*& workspace )
+void ProSHADE_internal_sphericalHarmonics::allocateComputationMemory ( proshade_unsign band, proshade_double*& inputReal, proshade_double*& inputImag, proshade_double*& outputReal, proshade_double*& outputImag, proshade_double*& shWeights, proshade_double*& tableSpaceHelper, fftw_complex*& workspace )
 {
     //================================================ Initialise local variables
     proshade_unsign oneDimmension                     = 2 * band;
@@ -55,8 +54,8 @@ void ProSHADE_internal_sphericalHarmonics::allocateComputationMemory ( proshade_
     workspace                                         = new fftw_complex    [(  8 * band * band ) +  ( 10 * band )];
     
     //================================================ Allocate table
-    tableSpaceHelper                                  = new proshade_double [static_cast<proshade_unsign> ( Reduced_Naive_TableSize ( band, band ) +
-                                                                                                            Reduced_SpharmonicTableSize ( band, band ) )];
+    tableSpaceHelper                                  = new proshade_double [static_cast<proshade_unsign> ( Reduced_Naive_TableSize ( static_cast< int > ( band ), static_cast< int > ( band ) ) +
+                                                                                                            Reduced_SpharmonicTableSize ( static_cast< int > ( band ), static_cast< int > ( band ) ) )];
     
     //================================================ Check memory allocation success
     ProSHADE_internal_misc::checkMemoryAllocation     ( inputReal,        __FILE__, __LINE__, __func__ );
@@ -168,7 +167,7 @@ void ProSHADE_internal_sphericalHarmonics::initialiseFFTWPlans ( proshade_unsign
     \param[in] fftPlan pointer to the variable where the Fourier transform was done to be freed.
     \param[in] dctPlan pointer to the variable where the 1D r2r Fourier transform was done to be freed.
  */
-void ProSHADE_internal_sphericalHarmonics::releaseSphericalMemory ( proshade_double*& inputReal, proshade_double*& inputImag, proshade_double*& outputReal, proshade_double*& outputImag, double*& tableSpaceHelper, double**& tableSpace, double*& shWeights, fftw_complex*& workspace, fftw_plan& fftPlan, fftw_plan& dctPlan, proshade_unsign band )
+void ProSHADE_internal_sphericalHarmonics::releaseSphericalMemory ( proshade_double*& inputReal, proshade_double*& inputImag, proshade_double*& outputReal, proshade_double*& outputImag, double*& tableSpaceHelper, double**& tableSpace, double*& shWeights, fftw_complex*& workspace, fftw_plan& fftPlan, fftw_plan& dctPlan )
 {
     //================================================ Release all memory related to SH
     delete[] inputReal;
@@ -180,10 +179,10 @@ void ProSHADE_internal_sphericalHarmonics::releaseSphericalMemory ( proshade_dou
     delete[] workspace;
             
     //================================================ Set pointers to NULL
-    tableSpaceHelper                                  = NULL;
-    tableSpace                                        = NULL;
-    shWeights                                         = NULL;
-    workspace                                         = NULL;
+    tableSpaceHelper                                  = nullptr;
+    tableSpace                                        = nullptr;
+    shWeights                                         = nullptr;
+    workspace                                         = nullptr;
           
     //================================================ Delete fftw plans
     fftw_destroy_plan                                 ( dctPlan );
@@ -221,16 +220,16 @@ void ProSHADE_internal_sphericalHarmonics::initialiseAllMemory ( proshade_unsign
     proshade_unsign oneDim                            = band * 2;
     
     //================================================ Allocate memory for local pointers
-    allocateComputationMemory                         ( band, inputReal, inputImag, outputReal, outputImag, shWeights, tableSpace, tableSpaceHelper, workspace );
+    allocateComputationMemory                         ( band, inputReal, inputImag, outputReal, outputImag, shWeights, tableSpaceHelper, workspace );
     
     //================================================ Within workspace pointers
     placeWithinWorkspacePointers                      ( workspace, oneDim, rres, ires, fltres, scratchpad );
     
     //================================================ Generate Seminaive and naive tables for Legendre Polynomials
-    tableSpace                                        = SemiNaive_Naive_Pml_Table ( band, band, tableSpaceHelper, reinterpret_cast<double*> ( workspace ) );
+    tableSpace                                        = SemiNaive_Naive_Pml_Table ( static_cast< int > ( band ), static_cast< int > ( band ), tableSpaceHelper, reinterpret_cast<double*> ( workspace ) );
     
     //================================================ Make weights for spherical transform
-    makeweights                                       ( band, shWeights );
+    makeweights                                       ( static_cast< int > ( band ), shWeights );
     
     //================================================ Initialize FFTW Plans
     initialiseFFTWPlans                               ( band, fftPlan, dctPlan, inputReal, inputImag, rres, ires, scratchpad );
@@ -307,8 +306,8 @@ void ProSHADE_internal_sphericalHarmonics::computeSphericalTransformCoeffs ( pro
     {
         //============================================ Real part calculation
         SemiNaiveReduced                              ( rres + ( bandIter * ( band * 2 ) ),
-                                                        band,
-                                                        bandIter,
+                                                        static_cast< int > ( band ),
+                                                        static_cast< int > ( bandIter ),
                                                         fltres,
                                                         scratchpad,
                                                         tablePml[bandIter],
@@ -321,8 +320,8 @@ void ProSHADE_internal_sphericalHarmonics::computeSphericalTransformCoeffs ( pro
         
         //============================================ Imaginary part calculation
         SemiNaiveReduced                              ( ires + ( bandIter * ( band * 2 ) ),
-                                                        band,
-                                                        bandIter,
+                                                        static_cast< int > ( band ),
+                                                        static_cast< int > ( bandIter ),
                                                         fltres,
                                                         scratchpad,
                                                         tablePml[bandIter],
@@ -368,8 +367,8 @@ void ProSHADE_internal_sphericalHarmonics::applyCondonShortleyPhase ( proshade_u
         powerOne                                     *= -1.0;
         for ( proshade_signed bandIter = order; bandIter < static_cast<proshade_signed> ( band ); bandIter++)
         {
-            hlp1                                      = seanindex (  order, bandIter, band );
-            hlp2                                      = seanindex ( -order, bandIter, band );
+            hlp1                                      = static_cast< proshade_unsign > ( seanindex ( static_cast< int > (  order ), static_cast< int > ( bandIter ), static_cast< int > ( band ) ) );
+            hlp2                                      = static_cast< proshade_unsign > ( seanindex ( static_cast< int > ( -order ), static_cast< int > ( bandIter ), static_cast< int > ( band ) ) );
                     
             shArray[hlp2][0]                          =  powerOne * static_cast<proshade_double> ( outputReal[hlp1] );
             shArray[hlp2][1]                          = -powerOne * static_cast<proshade_double> ( outputImag[hlp1] );
@@ -395,10 +394,10 @@ void ProSHADE_internal_sphericalHarmonics::applyCondonShortleyPhase ( proshade_u
 void ProSHADE_internal_sphericalHarmonics::computeSphericalHarmonics ( proshade_unsign band, proshade_double* sphereMappedData, proshade_complex*& shArray )
 {
     //================================================ Initialise local variables
-    proshade_double *inputReal = NULL, *inputImag = NULL, *outputReal = NULL, *outputImag = NULL;
-    double *shWeights = NULL, *tableSpaceHelper = NULL;
-    double** tablePml                                 = NULL;
-    fftw_complex* workspace                           = NULL;
+    proshade_double *inputReal = nullptr, *inputImag = nullptr, *outputReal = nullptr, *outputImag = nullptr;
+    double *shWeights = nullptr, *tableSpaceHelper = nullptr;
+    double** tablePml                                 = nullptr;
+    fftw_complex* workspace                           = nullptr;
     proshade_unsign oneDim                            = static_cast<proshade_unsign> ( band * 2 );
     proshade_double normCoeff                         = ( 1.0 / ( static_cast<proshade_double> ( band * 2 ) ) ) * sqrt( 2.0 * M_PI );
     
@@ -410,11 +409,11 @@ void ProSHADE_internal_sphericalHarmonics::computeSphericalHarmonics ( proshade_
     }
     
     //================================================ Within workspace pointers
-    proshade_double *rres = NULL, *ires = NULL, *fltres = NULL, *scratchpad = NULL, *rdataptr = NULL, *idataptr = NULL;
+    proshade_double *rres = nullptr, *ires = nullptr, *fltres = nullptr, *scratchpad = nullptr, *rdataptr = nullptr, *idataptr = nullptr;
     
     //================================================ FFTW Plans
-    fftw_plan fftPlan                                 = NULL;
-    fftw_plan dctPlan                                 = NULL;
+    fftw_plan fftPlan                                 = nullptr;
+    fftw_plan dctPlan                                 = nullptr;
     
     //================================================ Initialise all memory
     initialiseAllMemory                               ( band, inputReal, inputImag, outputReal, outputImag, shWeights, tablePml, tableSpaceHelper, workspace,
@@ -430,7 +429,7 @@ void ProSHADE_internal_sphericalHarmonics::computeSphericalHarmonics ( proshade_
     applyCondonShortleyPhase                          ( band, outputReal, outputImag, shArray );
     
     //================================================ Free memory
-    releaseSphericalMemory                            ( inputReal, inputImag, outputReal, outputImag, tableSpaceHelper, tablePml, shWeights, workspace, fftPlan, dctPlan, band );
+    releaseSphericalMemory                            ( inputReal, inputImag, outputReal, outputImag, tableSpaceHelper, tablePml, shWeights, workspace, fftPlan, dctPlan );
     
     //================================================ Done
     return ;
