@@ -14,12 +14,12 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.5.3
-    \date      FEB 2021
+    \version   0.7.6.0
+    \date      JUL 2021
  */
 
 //==================================================== Overinclusion protection
-#ifndef __PROSHADE_VERSION__
-#define __PROSHADE_VERSION__ "0.7.5.3 (FEB 2021)"
+#ifndef PROSHADE_VERSION
+#define PROSHADE_VERSION "0.7.6.0 (JUL 2021)"
 
 #endif
