@@ -14,20 +14,47 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.5.3
-    \date      FEB 2021
+    \version   0.7.6.0
+    \date      JUL 2021
  */
 
-//==================================================== Include getopt_port for python
-#if defined ( _WIN64 ) || defined ( _WIN32 )
-    #include <getopt_port/getopt.h>
-    #include <getopt_port/getopt.c>
+//==================================================== Do not use the following flags for the included files - this causes a lot of warnings that have nothing to do with ProSHADE
+#if defined ( __GNUC__ )
+    #pragma GCC diagnostic push
+    #pragma GCC diagnostic ignored "-Wpedantic"
+    #pragma GCC diagnostic ignored "-Wshadow"
+    #pragma GCC diagnostic ignored "-Wall"
+    #pragma GCC diagnostic ignored "-Wextra"
+    #pragma GCC diagnostic ignored "-Wdouble-promotion"
+    #pragma GCC diagnostic ignored "-Wconversion"
 #endif
 
+//==================================================== Do not use the following flags for the included files - this causes a lot of warnings that have nothing to do with ProSHADE
+#if defined ( __clang__ )
+    #pragma clang diagnostic push
+    #pragma clang diagnostic ignored "-Wpedantic"
+    #pragma clang diagnostic ignored "-Wshadow"
+    #pragma clang diagnostic ignored "-Wall"
+    #pragma clang diagnostic ignored "-Wextra"
+    #pragma clang diagnostic ignored "-Wdouble-promotion"
+    #pragma clang diagnostic ignored "-Weverything"
+#endif
+
+//==================================================== Remove MSVC C4996 Warnings caused by Gemmi code
+#if defined ( _MSC_VER )
+    #pragma warning ( disable:4996 )
+#endif
+
+//==================================================== Include getopt_port for python
+#include <getopt_port/getopt_port.h>
+#include <getopt_port/getopt_port.c>
+
 //==================================================== Include ProSHADE
 #include "ProSHADE.hpp"
 
-//==================================================== Include full ProSHADE (including cpp files looks horrible, but it is the only way I can find to stop PyBind11 from complaining)
+//==================================================== Include full ProSHADE - including cpp files looks horrible, but it is the only way I can find to stop PyBind11 from complaining on Windows10. I believe this has to do with windows not exporting symbols unless the __cdecl_dllexport is used, which for most functions is not yet there...
+#include "ProSHADE_precomputedValues.cpp"
+#include "ProSHADE_exceptions.cpp"
 #include "ProSHADE_misc.cpp"
 #include "ProSHADE_maths.cpp"
 #include "ProSHADE_tasks.cpp"
@@ -59,6 +86,21 @@ void    add_distancesClass                            ( pybind11::module& pyProS
 //==================================================== Remove the bindings that are not modifyable in python
 PYBIND11_MAKE_OPAQUE                                  ( std::vector < std::string > )
 
+//==================================================== Enable MSVC C4996 Warnings for the rest of the code
+#if defined ( _MSC_VER )
+    #pragma warning ( default:4996 )
+#endif
+
+//==================================================== Now the flags can be restored and used as per the CMakeLists.txt file.
+#if defined ( __GNUC__ )
+    #pragma GCC diagnostic pop
+#endif
+
+//==================================================== Now the flags can be restored and used as per the CMakeLists.txt file.
+#if defined ( __clang__ )
+    #pragma clang diagnostic pop
+#endif
+
 //==================================================== Include the other codes
 #include "pyProSHADE.cpp"
 #include "pyProSHADE_data.cpp"
@@ -74,7 +116,7 @@ PYBIND11_MODULE ( proshade, pyProSHADE )
     pyProSHADE.doc ( )                                = "Protein Shape Description and Symmetry Detection (ProSHADE) python module"; // Module docstring
     
     //================================================ Set the module version
-    pyProSHADE.attr ( "__version__" )                 = __PROSHADE_VERSION__;
+    pyProSHADE.attr ( "__version__" )                 = PROSHADE_VERSION;
 
     //================================================ Export the ProSHADE_Task enum
     pybind11::enum_ < ProSHADE_Task > ( pyProSHADE, "ProSHADE_Task" )
